@@ -1,5 +1,8 @@
-(defproject clojure-complete "0.2.2"
+(defproject clojure-complete "0.2.5"
   :description "Standalone completion library adapted from swank-clojure"
+  :license {:name "Eclipse Public License"
+            :url "http://www.eclipse.org/legal/epl-v10.html"}
+  :url "https://github.com/ninjudd/clojure-complete"
   :dependencies [[org.clojure/clojure "1.3.0"]]
   :profiles {
     :1.2 {:dependencies [[org.clojure/clojure "1.2.0"]]}
